@@ -477,6 +477,7 @@ PlatformTypeType = Literal["Linux", "MacOS", "Windows"]
 RebootOptionType = Literal["NoReboot", "RebootIfNeeded"]
 ResourceDataSyncS3FormatType = Literal["JsonSerDe"]
 ResourceTypeForTaggingType = Literal[
+    "Association",
     "Automation",
     "Document",
     "MaintenanceWindow",
@@ -537,6 +538,7 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
     "billingconductor",
     "braket",
@@ -579,6 +581,7 @@ ServiceName = Literal[
     "connect-contact-lens",
     "connectcampaigns",
     "connectparticipant",
+    "controltower",
     "cur",
     "customer-profiles",
     "databrew",
@@ -682,6 +685,7 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-user-subscriptions",
     "lightsail",
     "location",
     "logs",
@@ -735,6 +739,7 @@ ServiceName = Literal[
     "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
@@ -797,6 +802,7 @@ ServiceName = Literal[
     "storagegateway",
     "sts",
     "support",
+    "support-app",
     "swf",
     "synthetics",
     "textract",
@@ -897,6 +903,7 @@ RegionName = Literal[
     "eu-west-1",
     "eu-west-2",
     "eu-west-3",
+    "me-central-1",
     "me-south-1",
     "sa-east-1",
     "us-east-1",
