@@ -19,14 +19,14 @@ Usage::
     command_executed_waiter: CommandExecutedWaiter = client.get_waiter("command_executed")
     ```
 """
-from botocore.waiter import Waiter as Boto3Waiter
+from botocore.waiter import Waiter
 
 from .type_defs import WaiterConfigTypeDef
 
 __all__ = ("CommandExecutedWaiter",)
 
 
-class CommandExecutedWaiter(Boto3Waiter):
+class CommandExecutedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM.Waiter.CommandExecuted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters/#commandexecutedwaiter)
